pub type ComponentRegistry = HashMap<String, Box<dyn TuiComponent>>;Expand description
Registry that maps component type names to their TuiComponent implementations.
Aliased Type
pub struct ComponentRegistry { /* private fields */ }pub type ComponentRegistry = HashMap<String, Box<dyn TuiComponent>>;Registry that maps component type names to their TuiComponent implementations.
pub struct ComponentRegistry { /* private fields */ }