Surface renderer — entry point for rendering an A2UI component tree into a ratatui frame.
Structs
- Surface
Renderer - Renders a
SurfaceModelinto a ratatui frame by walking the component tree.
Surface renderer — entry point for rendering an A2UI component tree into a ratatui frame.
SurfaceModel into a ratatui frame by walking the component tree.